==> magento-module-saas-rma-sync-0.9.0.zip: Test/Unit/Event/RMAItemOptionProcessorTest.php <==
<?php
/************************************************************************
 *
 * ADOBE CONFIDENTIAL
 * ___________________
 *
 * Copyright 2023 Adobe
 * All Rights Reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of Adobe and its suppliers, if any. The intellectual
 * and technical concepts contained herein are proprietary to Adobe
 * and its suppliers and are protected by all applicable intellectual
 * property laws, including trade secret and copyright laws.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Adobe.
 * ************************************************************************
 */
declare(strict_types=1);

namespace Magento\SaaSOrderSync\Test\Unit\Core\SaaS;

use Magento\AdobeCommerceEventsClient\Event\Event;
use Magento\SaaSRMASync\Event\RMAItemOptionProcessor;
use Magento\SaaSRMASync\Sync\RMARepository;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

class RMAItemOptionProcessorTest extends TestCase
{
    private RMARepository&MockObject $rmaRepositoryMock;

    private RMAItemOptionProcessor $rmaItemOptionProcessor;

    protected function setUp(): void
    {
        $this->rmaRepositoryMock = $this->createMock(RMARepository::class);
        $this->rmaItemOptionProcessor = new RMAItemOptionProcessor($this->rmaRepositoryMock);
    }

    public function test_shouldReturnOptions_whenRMAEventsTriggered()
    {
        $event = $this->createMock(Event::class);
        $eventData = [
            'entity_id' => '1',
            'order_id' => '100',
            'order_increment_id' => '00100',
            'items' => [
                [
                    'entity_id' => '200',
                    'order_item_id' => '400',
                ],
            ],
        ];

        $expectedResult = [
            'entity_id' => '1',
            'order_id' => '100',
            'order_increment_id' => '00100',
            'items' => [
                [
                    'entity_id' => '200',
                    'order_item_id' => '400',
                    'options' => [
                        [
                            'label' => 'Resolution',
                            'value' => 'Exchange',
                        ],
                    ],
                ]
            ]
        ];

        $this->rmaRepositoryMock->expects($this->once())
            ->method('findRMAItemOptions')
            ->with(['200'])
            ->willReturn([
                [
                    'entity_id' => '200',
                    'attribute_id' => '456',
                    'value_id' => '789',
                    'label' => 'Resolution',
                    'value' => 'Exchange',
                ],
            ]);

        $result = $this->rmaItemOptionProcessor->process($event, $eventData);

        $this->assertEquals($expectedResult, $result);
    }
}

==> magento-module-saas-rma-sync-1.2.0.zip: Test/Unit/Event/RMAItemOptionProcessorTest.php <==
<?php
/************************************************************************
 *
 * ADOBE CONFIDENTIAL
 * ___________________
 *
 * Copyright 2023 Adobe
 * All Rights Reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of Adobe and its suppliers, if any. The intellectual
 * and technical concepts contained herein are proprietary to Adobe
 * and its suppliers and are protected by all applicable intellectual
 * property laws, including trade secret and copyright laws.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from Adobe.
 * ************************************************************************
 */
declare(strict_types=1);

namespace Magento\SaaSRMASync\Test\Unit\Event;

use Magento\AdobeCommerceEventsClient\Event\Event;
use Magento\SaaSRMASync\Event\RMAItemOptionProcessor;
use Magento\SaaSRMASync\Sync\RMARepository;
use PHPUnit\Framework\MockObject\MockObject;
use PHPUnit\Framework\TestCase;

class RMAItemOptionProcessorTest extends TestCase
{
    private RMARepository&MockObject $rmaRepositoryMock;

    private RMAItemOptionProcessor $rmaItemOptionProcessor;

    protected function setUp(): void
    {
        $this->rmaRepositoryMock = $this->createMock(RMARepository::class);
        $this->rmaItemOptionProcessor = new RMAItemOptionProcessor($this->rmaRepositoryMock);
    }

    public function test_shouldReturnOptions_whenRMAEventsTriggered()
    {
        $event = $this->createMock(Event::class);
        $eventData = [
            'entity_id' => '1',
            'order_id' => '100',
            'order_increment_id' => '00100',
            'items' => [
                [
                    'entity_id' => '200',
                    'order_item_id' => '400',
                ],
            ],
        ];

        $expectedResult = [
            'entity_id' => '1',
            'order_id' => '100',
            'order_increment_id' => '00100',
            'items' => [
                [
                    'entity_id' => '200',
                    'order_item_id' => '400',
                    'options' => [
                        [
                            'label' => 'Resolution',
                            'value' => 'Exchange',
                        ],
                    ],
                ]
            ]
        ];

        $this->rmaRepositoryMock->expects($this->once())
            ->method('findRMAItemOptions')
            ->with(['200'])
            ->willReturn([
                [
                    'entity_id' => '200',
                    'attribute_id' => '456',
                    'value_id' => '789',
                    'label' => 'Resolution',
                    'value' => 'Exchange',
                ],
            ]);

        $result = $this->rmaItemOptionProcessor->process($event, $eventData);

        $this->assertEquals($expectedResult, $result);
    }
}
